pub struct ApplyNativeConstraintOperation<'c> { /* private fields */ }Expand description
An apply_native_constraint operation. Apply a native constraint to a set of provided entities.
pdl.apply_native_constraint operations apply a native C++ constraint, that
has been registered externally with the consumer of PDL, to a given set of
entities and optionally return a number of values.
Example:
// Apply `myConstraint` to the entities defined by `input`, `attr`, and `op`.
pdl.apply_native_constraint "myConstraint"(%input, %attr, %op : !pdl.value, !pdl.attribute, !pdl.operation)
// Apply constraint `with_result` to `root`. This constraint returns an attribute.
%attr = pdl.apply_native_constraint "with_result"(%root : !pdl.operation) : !pdl.attributeImplementations
Sourceimpl<'c> ApplyNativeConstraintOperation<'c>
impl<'c> ApplyNativeConstraintOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> ApplyNativeConstraintOperationBuilder<'c, Unset, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> ApplyNativeConstraintOperationBuilder<'c, Unset, Unset, Unset>
Creates a builder.
pub fn results(&self) -> impl Iterator<Item = OperationResult<'c, '_>>
pub fn args(&self) -> impl Iterator<Item = Value<'c, '_>>
pub fn _name(&self) -> Result<StringAttribute<'c>, Error>
pub fn set_name(&mut self, value: StringAttribute<'c>)
pub fn is_negated(&self) -> Result<Attribute<'c>, Error>
pub fn set_is_negated(&mut self, value: Attribute<'c>)
pub fn remove_is_negated(&mut self) -> Result<(), Error>