EraseOperation

Struct EraseOperation 

pub struct EraseOperation<'c> { /* private fields */ }
An erase operation. Mark an input operation as erased.

pdl.erase operations are used within pdl.rewrite regions to specify that an input operation should be marked as erased. The semantics of this operation correspond with the eraseOp method on a PatternRewriter.

Example:

pdl.erase %root

Implementations

Source

impl<'c> EraseOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> EraseOperationBuilder<'c, Unset>

Creates a builder.

pub fn op_value(&self) -> Result<Value<'c, '_>, Error>